%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Maastricht Diffusion Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

.. toctree::
    :maxdepth: 2

    readme_latex
    concepts
    getting_started
    dynamic_modules
    configuration
    FAQ <faq>
    credits
    developers

